<?php
class ControllerExtensionAdvertiseUcc extends Controller {
    private $error = array();

    public function index() {
        $this->load->language('extension/advertise/ucc');
        $this->load->model('setting/setting');
        $this->load->model('extension/advertise/ucc');
        $this->load->model('localisation/language');
        $this->document->setTitle($this->language->get('heading_title'));

        $data = $this->model_setting_setting->getSetting('advertise_ucc');
        if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate()) {
            if (empty($this->request->post['advertise_ucc_communication_password']) && !empty($data['advertise_ucc_communication_password'])) {
                $this->request->post['advertise_ucc_communication_password'] = $data['advertise_ucc_communication_password'];
            }
            $this->model_setting_setting->editSetting('advertise_ucc', $this->request->post);
            $this->session->data['success'] = $this->language->get('text_success');
            $this->response->redirect($this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=advertise', true));
        }
        if (isset($this->error['warning'])) {
            $data['error_warning'] = $this->error['warning'];
        } else {
            $data['error_warning'] = '';
        }
        if (isset($this->session->data['success'])) {
            $data['success'] = $this->session->data['success'];
            unset($this->session->data['success']);
        } else {
            $data['success'] = '';
        }

        $data['breadcrumbs'] = array();
        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('text_home'),
            'href' => $this->url->link('common/dashboard', 'user_token=' . $this->session->data['user_token'], true)
        );
        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('text_extension'),
            'href' => $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=advertise', true)
        );
        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('heading_title'),
            'href' => $this->url->link('extension/advertise/ucc', 'user_token=' . $this->session->data['user_token'], true)
        );
        $data['action'] = $this->url->link('extension/advertise/ucc', 'user_token=' . $this->session->data['user_token'], true);
        $data['rehook_events'] = $this->url->link('extension/advertise/ucc/hook_events', 'user_token=' . $this->session->data['user_token'], true);
        $data['cancel'] = $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=advertise', true);

        $data['header'] = $this->load->controller('common/header');
        $data['column_left'] = $this->load->controller('common/column_left');
        $data['footer'] = $this->load->controller('common/footer');

        $this->response->setOutput($this->load->view('extension/advertise/ucc', $data));
    }

    public function install() {
        $this->load->model('extension/advertise/ucc');
        $this->hook_events(true);
    }

    public function uninstall() {
        $this->load->model('extension/advertise/ucc');

        $this->model_extension_advertise_ucc->dropData();
        $this->model_extension_advertise_ucc->unhookEvents();
    }

    public function hook_events($inline = false) {
        $this->load->language('extension/advertise/ucc');
        $this->load->model('extension/advertise/ucc');

        $this->model_extension_advertise_ucc->unhookEvents();
        $this->model_extension_advertise_ucc->hookEvents();

        if (!$inline) {
            $this->session->data['success'] = $this->language->get('text_success_events');

            $this->response->redirect($this->url->link('extension/advertise/ucc', 'user_token=' . $this->session->data['user_token'], true));
        }
    }

    protected function validate() {
        if (!$this->user->hasPermission('modify', 'extension/advertise/ucc')) {
            $this->error['warning'] = $this->language->get('error_permission');
        }

        if ($this->validatePluginToken($this->request->post['advertise_ucc_verification_id']) {
            $this->error['warning'] = $this->language->get('verification_id');
        }

        return !$this->error;
    }

    private function validatePluginToken($uccPluginToken) {
        $version = 'UNKNOWN';
        if (isset(VERSION)) {
            $version = VERSION;
        }

        $apiUrl = 'https://api.ucancommerce.com/api/v1/plugin/installation';
        $data = json_encode([
           'pluginToken' => strval($uccPluginToken),
           'shopPlatform' => 'OPENCART',
           'platformVersion' => $version,
        ]);

        $headers = array(
            "Content-Type: application/json",
        );

        $curl = curl_init($apiUrl);
        curl_setopt($curl, CURLOPT_URL, $apiUrl);
        curl_setopt($curl, CURLOPT_POST, true);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($curl, CURLOPT_POSTFIELDS, $data);

        curl_exec($curl);

        $code = curl_getinfo($curl, CURLINFO_HTTP_CODE);
        curl_close($curl);

        if ($code == 200) {
            return true;
        }

        return false;
    }
}